@@ -1,6 +1,6 @@
 #This is a dummy file so CPAN will find a VERSION
 package Authen::PAM;
-$VERSION = "0.08";
+$VERSION = "0.10";
 #This is to make sure require will return an error
 0;
 __END__
@@ -51,7 +51,7 @@ function is used (Authen::PAM::pam_default_conv).
 
 The $flags argument is optional for all functions which use it
 except for pam_setcred. The $pam_status argument is also optional for
-pam_end function. Both of this arguments will be set to 0 if not given.
+pam_end function. Both of these arguments will be set to 0 if not given.
 
 The names of some constants from the PAM library have changed over the
 time. You can use any of the known names for a given constant although
@@ -72,9 +72,13 @@ pam_getenvlist).
 If you prefer to use an object oriented style for accessing the PAM
 library here is the interface:
 
+  use Authen::PAM qw(:constants);
+
   $pamh = new Authen::PAM($service_name, $user);
   $pamh = new Authen::PAM($service_name, $user, $conv_func);
 
+  ref($pamh) || die "Error code $pamh during PAM init!";
+
   $retval = $pamh->pam_authenticate($flags);
   $retval = $pamh->pam_setcred($flags);
   $retval = $pamh->pam_acct_mgmt($flags);
@@ -120,32 +124,32 @@ or the same thing but using OO style:
 =head2 Conversation function format
 
 When starting the PAM the user must supply a conversation function.
-It is used for interaction between the PAM modules and the user.
-The argument of the function is a list of pairs ($msg_type, $msg)
-and it must return a list with the same number of pairs ($resp_retcode, $resp)
-with replies to the input messages. For now the $resp_retcode is not used
-and must be always set to 0.  In addition the user must append to
-the end of the resulting list the return code of the conversation function
-(usually PAM_SUCCESS).
+It is used for interaction between the PAM modules and the user. The
+argument of the function is a list of pairs ($msg_type, $msg) and it
+must return a list with the same number of pairs ($resp_retcode,
+$resp) with replies to the input messages. For now the $resp_retcode
+is not used and must be always set to 0. In addition the user must
+append to the end of the resulting list the return code of the
+conversation function (usually PAM_SUCCESS).
 
 Here is a sample form of the PAM conversation function:
 
-sub pam_conv_func {
-    my @res;
-    while ( @_ ) {
-        my $msg_type = shift;
-        my $msg = shift;
+  sub pam_conv_func {
+      my @res;
+      while ( @_ ) {
+          my $msg_type = shift;
+          my $msg = shift;
 
-        print $msg;
+          print $msg;
 
-	# switch ($msg_type) { obtain value for $ans; }
+	 # switch ($msg_type) { obtain value for $ans; }
 
-        push @res, 0;
-        push @res, $ans;
-    }
-    push @res, PAM_SUCCESS;
-    return @res;
-}
+         push @res, 0;
+         push @res, $ans;
+      }
+      push @res, PAM_SUCCESS;
+      return @res;
+  }
 
 
 =head1 COMPATIBILITY
@@ -153,6 +157,13 @@ sub pam_conv_func {
 This module was tested with the following versions of the Linux-PAM library:
 0.50, 0.56, 0.59 and 0.65.
 
+The following constant names: PAM_AUTHTOKEN_REQD, PAM_CRED_ESTABLISH,
+PAM_CRED_DELETE, PAM_CRED_REINITIALIZE, PAM_CRED_REFRESH are used by
+some older version of the Linux-PAM library and are not exported by
+default. If you really want them, then load the module with
+
+  use Authen::PAM qw(:DEFAULT :old);
+
 This module still does not support some of the new Linux-PAM
 functions such as pam_system_log.
 
@@ -162,6 +173,12 @@ PAM Application developer's Manual
 
 =head1 AUTHOR
 
-Nikolay Pelov <nikip@iname.com>
+Nikolay Pelov nikip@iname.com
+
+=head1 COPYRIGHT
+
+Copyright (c) 1998-2000 Nikolay Pelov. All rights reserved. This
+program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =cut
